@@ -1,8 +1,5 @@
 package Devel::StackTrace::Frame;
-{
-  $Devel::StackTrace::Frame::VERSION = '1.29';
-}
-
+$Devel::StackTrace::Frame::VERSION = '1.32';
 use strict;
 use warnings;
 
@@ -158,49 +155,51 @@ Devel::StackTrace::Frame - A single frame in a stack trace
 
 =head1 VERSION
 
-version 1.29
+version 1.32
 
 =head1 DESCRIPTION
 
 See L<Devel::StackTrace> for details.
 
+=for Pod::Coverage new
+
 =head1 METHODS
 
-See the L<caller> documentation for more information on what these
+See Perl's C<caller()> documentation for more information on what these
 methods return.
 
-=over 4
+=head2 $frame->package()
 
-=item * $frame->package
+=head2 $frame->filename()
 
-=item * $frame->filename
+=head2 $frame->line()
 
-=item * $frame->line
+=head2 $frame->subroutine()
 
-=item * $frame->subroutine
+=head2 $frame->hasargs()
 
-=item * $frame->hasargs
+=head2 $frame->wantarray()
 
-=item * $frame->wantarray
-
-=item * $frame->evaltext
+=head2 $frame->evaltext()
 
 Returns undef if the frame was not part of an eval.
 
-=item * $frame->is_require
+=head2 $frame->is_require()
 
 Returns undef if the frame was not part of a require.
 
-=item * $frame->args
+=head2 $frame->args()
 
-Returns the arguments passed to the frame.  Note that any arguments
-that are references are returned as references, not copies.
+Returns the arguments passed to the frame.  Note that any arguments that are
+references are returned as references, not copies.
 
-=item * $frame->hints
+=head2 $frame->hints()
 
-=item * $frame->bitmask
+=head2 $frame->bitmask()
 
-=back
+=head2 $frame->as_string()
+
+Returns a string containing a description of the frame.
 
 =head1 AUTHOR
 
@@ -208,7 +207,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
